@@ -557,3 +557,77 @@ test_that("simple fuzz test of group()", {
 
 })
 
+test_that("group() works with group_by()", {
+  xpectr::set_test_seed(42)
+
+  df <- data.frame(
+    "n" = c(1, 2, 3, 4, 2, 1, 5, 2, 1, 9),
+    "s" = c(4, 4, 4, 4, 7, 7, 7, 7, 1, 1),
+    "c" = as.character(c(4, 4, 6, 6, 7, 7, 7, 8, 8, 1)),
+    "f" = as.factor(as.character(c(4, 4, 6, 6, 7, 7, 7, 8, 8, 1))),
+    stringsAsFactors = FALSE
+  )
+
+  ## Testing 'xpectr::suppress_mw( df %>% dplyr::group_by(...'              ####
+  ## Initially generated by xpectr
+  xpectr::set_test_seed(42)
+  # Assigning output
+  output_19148 <- xpectr::suppress_mw(
+      df %>%
+        dplyr::group_by(s) %>%
+        group(n = 2)
+    )
+  # Testing class
+  expect_equal(
+    class(output_19148),
+    c("grouped_df", "tbl_df", "tbl", "data.frame"),
+    fixed = TRUE)
+  # Testing column values
+  expect_equal(
+    output_19148[["n"]],
+    c(1, 9, 1, 2, 3, 4, 2, 1, 5, 2),
+    tolerance = 1e-4)
+  expect_equal(
+    output_19148[["s"]],
+    c(1, 1, 4, 4, 4, 4, 7, 7, 7, 7),
+    tolerance = 1e-4)
+  expect_equal(
+    output_19148[["c"]],
+    c("8", "1", "4", "4", "6", "6", "7", "7", "7", "8"),
+    fixed = TRUE)
+  expect_equal(
+    output_19148[["f"]],
+    structure(c(5L, 1L, 2L, 2L, 3L, 3L, 4L, 4L, 4L, 5L), .Label = c("1",
+      "4", "6", "7", "8"), class = "factor"))
+  expect_equal(
+    output_19148[[".groups"]],
+    structure(c(1L, 2L, 1L, 1L, 2L, 2L, 1L, 1L, 2L, 2L), .Label = c("1",
+      "2"), class = "factor"))
+  # Testing column names
+  expect_equal(
+    names(output_19148),
+    c("n", "s", "c", "f", ".groups"),
+    fixed = TRUE)
+  # Testing column classes
+  expect_equal(
+    xpectr::element_classes(output_19148),
+    c("numeric", "numeric", "character", "factor", "factor"),
+    fixed = TRUE)
+  # Testing column types
+  expect_equal(
+    xpectr::element_types(output_19148),
+    c("double", "double", "character", "integer", "integer"),
+    fixed = TRUE)
+  # Testing dimensions
+  expect_equal(
+    dim(output_19148),
+    c(10L, 5L))
+  # Testing group keys
+  expect_equal(
+    colnames(dplyr::group_keys(output_19148)),
+    c("s", ".groups"),
+    fixed = TRUE)
+  ## Finished testing 'xpectr::suppress_mw( df %>% dplyr::group_by(...'     ####
+
+
+})
